The Claims Management Services Tribunal was created by the Compensation Act 2006 to hear appeals against decisions of the Claims Management Services Regulator and references from the Regulator concerning the professional conduct of persons providing claims management services. In 2010 its functions were transferred to the General Regulatory Chamber of the First-tier Tribunal, which hears appeals against decisions made by government regulatory bodies.
